<template>
  <div class="searchbar-container" v-if="showQueryState">
    <BlSearchbar
      v-model.trim="searchValue"
      placeholder="搜索姓名/身份证号"
      @search="handleSearch"
      @change="handleSearch"
    ></BlSearchbar>
  </div>
  <InfiniteLoading scrollViewClassName="common-infinite-scroll-list" v-bind="infiniteLoadingProps">
    <template #renderItem="{ item }">
      <FlexJobCard
        :name="item.name"
        :genderType="item.genderType"
        :age="item.age"
        :educationalLevel="item.educationalLevel"
        :arrangeCount="item.arrangeCount"
        :showFooterLeft="false"
      >
        <template #footerRight>
          <nut-button v-if="showQueryState" type="primary" @click="handleArrange(item)"
            >安排</nut-button
          >
          <div v-else class="batch-task-card-status">已安排</div>
        </template>
      </FlexJobCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import Taro from '@tarojs/taro';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import _ from 'lodash';
import { Message, trim } from '@12333/utils';
import { FlexJobCard } from '@12333/components';

defineOptions({
  name: 'InnerPage',
});

const searchValue = ref('');
const router = Taro.useRouter();
const taskId = router.params?.taskId ?? '';
const status = router.params?.status ?? '';
const queryState = reactive({
  searchValueTrim: '',
});

const showQueryState = computed(() => {
  return status === 'arrange';
});

const handleSearch = _.debounce(function () {
  queryState.searchValueTrim = trim(searchValue.value);
}, 300);

const { infiniteLoadingProps, invalidateQueries } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskWorkerArrangeListInput = {
      searchKeys: queryState.searchValueTrim,
      flexTaskId: taskId,
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'lastShelfTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskWorkerArrangeList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskWorkerArrangeList', queryState],
  }
);

async function handleArrange(item: API.GetNewestWorkerListOutput) {
  try {
    let params: API.TaskWorkerArrangeInput = {
      flexTaskId: taskId,
      flexWorkerId: item.userId,
      arrange: true,
    };
    let res = await flexWorkerServices.taskWorkerArrange(params);
    if (res) {
      Message.success('已安排');
      invalidateQueries();
    }
  } catch (error) {}
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.searchbar-container {
  padding: boleGetCssVar('size', 'body-padding-h');
  padding-top: 0;
}

.batchTaskList-page-wrapper {
  .batch-task-card-status {
    line-height: 52px;
    color: boleGetCssVar('text-color', 'primary');
    font-size: 24px;
  }
}
</style>
